﻿using BPA.MES.Base.Application.Entitys.KepData;
using FreeRedis;
using Furion.ClayObject.Extensions;
using Furion.RemoteRequest;
using Newtonsoft.Json;
//using ServiceStack.Redis;
using SqlSugar;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using Yitter.IdGenerator;

namespace BPA.MES.Base.Application.Services.KepServerDataService.Services
{
    [AllowAnonymous]
    [ApiDescriptionSettings("大屏数据", Order = 4, Name = "KepData", Tag = "大屏数据", KeepName = true, SplitCamelCase = true, KeepVerb = true)]
    public class KepDataService:  IKepDataService,ITransient, IDynamicApiController
    {
       

        private readonly ISqlSugarClient _dbContext;
        public KepDataService(ISqlSugarClient db)
        {
            _dbContext = db;
        }

       


        [HttpGet]
        [AllowAnonymous]
        public Task<bool> CodeFirst()
        {
            var types = Assembly.Load("BPA.MES.Base.Application").GetTypes()
                .Where(x => x.GetCustomAttribute<SugarTable>() != null
                            && x.Namespace == "BPA.MES.Base.Application.Entitys.KepData").ToArray();
            _dbContext.CodeFirst.InitTables(types);
            return Task.FromResult(true);
        }


        /// <summary>
        /// 添加报警限制
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost]
        [AllowAnonymous]
        public async Task<bool> AddDataVAlarmLimit(DataVAlarmLimit inputDto)
        {
            inputDto.Id = YitIdHelper.NextId().ToString();
            var res = await _dbContext.Insertable<DataVAlarmLimit>(inputDto).ExecuteCommandAsync();
            return res > 0;
        }

        /// <summary>
        /// 修改报警限制
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost]
        [AllowAnonymous]
        public async Task<bool> UpdateDataVAlarmLimit(DataVAlarmLimit inputDto)
        {
            var res = await _dbContext.Updateable<DataVAlarmLimit>(inputDto).ExecuteCommandAsync();
            return res > 0;
        }

        /// <summary>
        /// 获取报警限制
        /// </summary>
        /// <returns></returns>
        [HttpPost]
        [AllowAnonymous]
        public async Task<SqlSugarPagedList<DataVAlarmLimit>> GetDataVAlarmLimitList(RequestPage input)
        {
            var entity = await _dbContext.Queryable<DataVAlarmLimit>()
                .ToPagedListAsync(input.PageIndex, input.PageSize);
            SqlSugarPagedList<DataVAlarmLimit> output = entity.Adapt<SqlSugarPagedList<DataVAlarmLimit>>();
            return output;
        }

        /// <summary>
        /// 删除报警限制
        /// </summary>
        /// <returns></returns>
        [HttpPost]
        [AllowAnonymous]
        public async Task<bool> DelDataVAlarmLimitList(string id)
        {
            var res = await _dbContext.Deleteable<DataVAlarmLimit>().Where(x=>x.Id==id).ExecuteCommandAsync();
            return res>0;
        }

        [HttpGet]
        [AllowAnonymous]
        public Dictionary<string, string> GetDataVList()
        {
          
           // var client = new ServiceStack.Redis.RedisClient("10.2.1.21", 6379, "1178661552398188544");

            //var client = new RedisClient("10.2.1.21:6379,password=1178661552398188544,defaultDatabase=13");
           
          
            try
            {
                var client = new FreeRedis.RedisClient("127.0.0.1:6379,defaultDatabase=0");
                var res = new Dictionary<string, string>();

                for (int i = 1; i <= 28; i++)
                {
                    var str = "ns=2;s=WFZ.Device1.A" + i;
                    var value = client.Get<string>(str);
                    if (!string.IsNullOrEmpty(value)&&i!=4)
                    {
                        if (value.Length>=4)
                        {
                            value = value.Substring(0, 2);
                        }
                    }
                    res.Add("Device1.A" + i, value);
                }
                for (int i = 1; i <=31; i++)
                {
                    var str = "ns=2;s=WFZ.Device2.A" + i;
                    var value = client.Get<string>(str);
                    if (!string.IsNullOrEmpty(value) )
                    {
                        if (value.Length >= 4)
                        {
                            value = value.Substring(0, 2);
                        }
                    }
                    res.Add("Device2.A" + i, value);
                }
                for (int i = 1; i <=7; i++)
                {
                    var str = "ns=2;s=WFZ.Device3.A" + i;
                    var value = client.Get<string>(str);
                    if (!string.IsNullOrEmpty(value) && i != 4)
                    {
                        if (value.Length >= 4)
                        {
                            value = value.Substring(0, 5);
                        }
                    }
                    res.Add("Device3.A" + i, value);
                }
                for (int i = 1; i <= 1; i++)
                {
                    var str = "ns=2;s=WFZ.Device4.A" + i;
                    var value = client.Get<string>(str);
                    res.Add("Device4.A" + i, value);
                }
                return res;
            }
            catch (Exception e)
            {
                var res = new Dictionary<string, string>();
                Console.WriteLine(e);
                return res;

            }
          
        }

        [HttpGet]
        [AllowAnonymous]
        public async Task<List<List<string>>> GetLogsAsync()
        {
            var result = new List<List<string>>();
            var entity = await _dbContext.Queryable<AlarmLog>().Where(x=>x.CreateTime.Date==DateTime.Now.Date).ToListAsync();

            foreach (var item in entity)
            {
                var data = new List<string>();
                var thisData = new object();

                thisData = item.GetType().GetProperty("Name").GetValue(item, null);
                data.Add(thisData == null ? "" : thisData.ToString());
                thisData = item.GetType().GetProperty("ValueStr").GetValue(item, null);
                data.Add(thisData == null ? "" : thisData.ToString());
                thisData = item.GetType().GetProperty("CreateTime").GetValue(item, null);
                data.Add(thisData == null ? "" : thisData.ToString());

                result.Add(data);
            }
            return result;
        }
    }
}
